==> ejc-settle-impl-3.0.0-20250122.023702-146-sources.jar: com/ejianc/business/settle/service/ISettlementCenterDcDrwgrpInfoService.java <==
package com.ejianc.business.settle.service;

import com.ejianc.business.settle.bean.SettlementCenterDcDrwgrpInfoEntity;
import com.ejianc.business.settle.bean.SettlementCenterDcDrwgrpInfoVO;
import com.ejianc.framework.skeleton.template.IBaseService;

import java.util.List;
import java.util.Map;

/**
 * 结算中心卷册信息表
 *
 * @author generator
 */
public interface ISettlementCenterDcDrwgrpInfoService extends IBaseService<SettlementCenterDcDrwgrpInfoEntity> {



    List<Map> getRankingListForYear(Long major,List<Long> departmentIds,List<Long> commonOrgIds);

    List<Map> getRankingListForMonth(Long major,List<Long> departmentIds,List<Long> commonOrgIds);

    List<Map> getRankingListWithOrder(Long major,List<Long> departmentIds,List<Long> commonOrgIds,String order);

    List<Map> getProjectLedgerList(String order);
    List<Map> getMajorLedgerList(String order);

    List<Map> getProjectStatisticsLedgerList(List<String> projectIds,List<Long> departmentIds,List<Long> commonOrgIds,Integer pageStart, Integer pageSize);
    Integer countProjectStatisticsLedgerList(List<String> projectIds,List<Long> departmentIds,List<Long> commonOrgIds);

    List<Map> queryAllProject(List<Long> departmentIds,List<Long> commonOrgIds);

    List<Map> getMajorStatisticsLedgerList(Long major,List<Long> departmentIds,List<Long> commonOrgIds,Integer pageStart, Integer pageSize);
    Integer countMajorStatisticsLedgerList(Long major,List<Long> departmentIds,List<Long> commonOrgIds);

    List<SettlementCenterDcDrwgrpInfoVO> queryNeedAddDetailData();

}

==> ejc-settle-impl-3.0.0-20250826.072840-169-sources.jar: com/ejianc/business/settle/service/ISettlementCenterDcDrwgrpInfoService.java <==
package com.ejianc.business.settle.service;

import com.ejianc.business.settle.bean.SettlementCenterDcDrwgrpInfoEntity;
import com.ejianc.business.settle.bean.SettlementCenterDcDrwgrpInfoVO;
import com.ejianc.framework.core.response.CommonResponse;
import com.ejianc.framework.skeleton.template.IBaseService;
import org.springframework.web.bind.annotation.RequestBody;

import java.util.List;
import java.util.Map;

/**
 * 结算中心卷册信息表
 *
 * @author generator
 */
public interface ISettlementCenterDcDrwgrpInfoService extends IBaseService<SettlementCenterDcDrwgrpInfoEntity> {



    List<Map> getRankingListForYear(Long major,List<Long> departmentIds,List<Long> commonOrgIds);

    List<Map> getRankingListForMonth(Long major,List<Long> departmentIds,List<Long> commonOrgIds);

    List<Map> getRankingListWithOrder(Long major,List<Long> departmentIds,List<Long> commonOrgIds,String order);

    List<Map> getProjectLedgerList(String order);
    List<Map> getMajorLedgerList(String order);

    List<Map> getProjectStatisticsLedgerList(List<String> projectIds,List<Long> departmentIds,List<Long> commonOrgIds,Integer pageStart, Integer pageSize);
    Integer countProjectStatisticsLedgerList(List<String> projectIds,List<Long> departmentIds,List<Long> commonOrgIds);

    List<Map> queryAllProject(List<Long> departmentIds,List<Long> commonOrgIds);

    List<Map> getMajorStatisticsLedgerList(Long major,List<Long> departmentIds,List<Long> commonOrgIds,Integer pageStart, Integer pageSize);
    Integer countMajorStatisticsLedgerList(Long major,List<Long> departmentIds,List<Long> commonOrgIds);

    List<SettlementCenterDcDrwgrpInfoVO> queryNeedAddDetailData();

    public CommonResponse<SettlementCenterDcDrwgrpInfoVO> saveOrUpdateDcDrwgrpInfo(SettlementCenterDcDrwgrpInfoVO saveOrUpdateVO);

}
